==> zio-aws-nimble_2.13-5.17.153.1-sources.jar: zio/aws/nimble/model/ListEulasResponse.scala <==
package zio.aws.nimble.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListEulasResponse(
    eulas: Option[Iterable[zio.aws.nimble.model.Eula]] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.nimble.model.ListEulasResponse = {
    import ListEulasResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.nimble.model.ListEulasResponse
      .builder()
      .optionallyWith(
        eulas.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.eulas)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.nimble.model.ListEulasResponse.ReadOnly =
    zio.aws.nimble.model.ListEulasResponse.wrap(buildAwsValue())
}
object ListEulasResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.nimble.model.ListEulasResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.nimble.model.ListEulasResponse =
      zio.aws.nimble.model.ListEulasResponse(
        eulas.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def eulas: Option[List[zio.aws.nimble.model.Eula.ReadOnly]]
    def nextToken: Option[String]
    def getEulas: ZIO[Any, AwsError, List[zio.aws.nimble.model.Eula.ReadOnly]] =
      AwsError.unwrapOptionField("eulas", eulas)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.nimble.model.ListEulasResponse
  ) extends zio.aws.nimble.model.ListEulasResponse.ReadOnly {
    override val eulas: Option[List[zio.aws.nimble.model.Eula.ReadOnly]] = scala
      .Option(impl.eulas())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.nimble.model.Eula.wrap(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.nimble.model.ListEulasResponse
  ): zio.aws.nimble.model.ListEulasResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-nimble_2.13-5.17.195.2-sources.jar: zio/aws/nimble/model/ListEulasResponse.scala <==
package zio.aws.nimble.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListEulasResponse(
    eulas: Optional[Iterable[zio.aws.nimble.model.Eula]] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.nimble.model.ListEulasResponse = {
    import ListEulasResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.nimble.model.ListEulasResponse
      .builder()
      .optionallyWith(
        eulas.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.eulas)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.nimble.model.ListEulasResponse.ReadOnly =
    zio.aws.nimble.model.ListEulasResponse.wrap(buildAwsValue())
}
object ListEulasResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.nimble.model.ListEulasResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.nimble.model.ListEulasResponse =
      zio.aws.nimble.model.ListEulasResponse(
        eulas.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def eulas: Optional[List[zio.aws.nimble.model.Eula.ReadOnly]]
    def nextToken: Optional[String]
    def getEulas: ZIO[Any, AwsError, List[zio.aws.nimble.model.Eula.ReadOnly]] =
      AwsError.unwrapOptionField("eulas", eulas)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.nimble.model.ListEulasResponse
  ) extends zio.aws.nimble.model.ListEulasResponse.ReadOnly {
    override val eulas: Optional[List[zio.aws.nimble.model.Eula.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.eulas())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.nimble.model.Eula.wrap(item)
          }.toList
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.nimble.model.ListEulasResponse
  ): zio.aws.nimble.model.ListEulasResponse.ReadOnly = new Wrapper(impl)
}
